@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_SERIALIZER_KCALCORE_H
-#define AKONADI_SERIALIZER_KCALCORE_H
+#pragma once
 
 #include <QObject>
 
@@ -38,4 +37,3 @@ private:
 };
 }
 
-#endif
