@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef _AKONADI_CALENDAR_CLIPBOARD_H
-#define _AKONADI_CALENDAR_CLIPBOARD_H
+#pragma once
 
 #include "akonadi-calendar_export.h"
 #include "calendarbase.h"
@@ -83,4 +82,3 @@ private:
 };
 }
 
-#endif
