@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_FREEBUSYDOWNLOADJOB_P_H
-#define AKONADI_FREEBUSYDOWNLOADJOB_P_H
+#pragma once
 
 #include <KJob>
 #include <QUrl>
@@ -41,4 +40,3 @@ private:
 };
 }
 
-#endif // FREEBUSYMANAGER_P_H
