@@ -570,7 +570,7 @@ void FreeBusyManagerPrivate::onHandlesFreeBusy(const QString &email, bool handle
         return;
     }
 
-    auto *iface = dynamic_cast<QDBusInterface *>(sender());
+    auto iface = dynamic_cast<QDBusInterface *>(sender());
     if (!iface) {
         return;
     }
@@ -632,7 +632,7 @@ void FreeBusyManagerPrivate::onFreeBusyRetrieved(const QString &email, const QSt
         return;
     }
 
-    auto *iface = dynamic_cast<QDBusInterface *>(sender());
+    auto iface = dynamic_cast<QDBusInterface *>(sender());
     if (!iface) {
         return;
     }
